pub(crate) struct RootSetup {
luks_device: Option<String>,
pub(crate) device_info: Device,
pub(crate) physical_root_path: Utf8PathBuf,
pub(crate) physical_root: Dir,
pub(crate) target_root_path: Option<Utf8PathBuf>,
pub(crate) rootfs_uuid: Option<String>,
skip_finalize: bool,
boot: Option<MountSpec>,
pub(crate) kargs: CmdlineOwned,
}Fields
luks_device: Option<String>device_info: Devicephysical_root_path: Utf8PathBufAbsolute path to the location where we’ve mounted the physical root filesystem for the system we’re installing.
physical_root: DirDirectory file descriptor for the above physical root.
target_root_path: Option<Utf8PathBuf>Target root path /target.
rootfs_uuid: Option<String>skip_finalize: boolTrue if we should skip finalizing
boot: Option<MountSpec>kargs: CmdlineOwnedImplementations
Sourceimpl RootSetup
impl RootSetup
Sourcepub(crate) fn get_boot_uuid(&self) -> Result<Option<&str>>
pub(crate) fn get_boot_uuid(&self) -> Result<Option<&str>>
Get the UUID= mount specifier for the /boot filesystem; if there isn’t one, the root UUID will be returned.
Sourcepub(crate) fn boot_mount_spec(&self) -> Option<&MountSpec>
pub(crate) fn boot_mount_spec(&self) -> Option<&MountSpec>
Get the boot mount spec, if a separate /boot partition exists.
fn into_storage(self) -> (Utf8PathBuf, Option<String>)